@@ -616,6 +616,7 @@ def _get_mesos_spark_env(
         'spark.mesos.constraints': f'pool:{paasta_pool}',
         'spark.mesos.executor.docker.forcePullImage': 'true',
         'spark.mesos.principal': 'spark',
+        'spark.shuffle.useOldFetchProtocol': 'true',
         **auth_configs,
         **_get_mesos_docker_volumes_conf(
             user_spark_opts, extra_volumes,
@@ -902,13 +903,13 @@ def compute_requested_memory_overhead(spark_opts: Mapping[str, str], executor_me
 
 def get_signalfx_url(spark_conf: Mapping[str, str]) -> str:
     return (
-        'https://app.signalfx.com/#/dashboard/DJzYJDkAcAA?density=4'
+        'https://app.signalfx.com/#/dashboard/FOjL2yRAcAA?density=4'
         '&variables%5B%5D=Instance%3Dinstance_name:'
         '&variables%5B%5D=Service%3Dservice_name:%5B%22spark%22%5D'
         f"&variables%5B%5D=PaaSTA%20Cluster%3Dpaasta_cluster:{spark_conf['spark.executorEnv.PAASTA_CLUSTER']}"
         f"&variables%5B%5D=PaaSTA%20Service%3Dpaasta_service:{spark_conf['spark.executorEnv.PAASTA_SERVICE']}"
         f"&variables%5B%5D=PaaSTA%20Instance%3Dpaasta_instance:{spark_conf['spark.executorEnv.PAASTA_INSTANCE']}"
-        '&startTime=-6h&endTime=Now'
+        '&startTime=-1h&endTime=Now'
     )
 
 
